@@ -20,6 +20,8 @@ import time
 
 from azure.core.exceptions import HttpResponseError
 
+from clusterondemandazure.azure_actions.credentials import AzureApiHelper
+
 log = logging.getLogger("azure_action")
 
 
@@ -61,6 +63,7 @@ def unthrottle(fun, backoffs):
                 log.debug("Caught a throttling http code, will retry...")
                 time.sleep(backoff_time)
             else:
+                AzureApiHelper.log_error_details(e)
                 raise
 
     raise RetryLimitReached("Reached limit of retries")
