@@ -74,27 +74,40 @@ class ClusterCommand(object):
                 "Region %s does not exist." % config["azure_location"]
             )
 
-    def _validate_vmsize(self):
+    def _validate_vmsize(self, head_node_type, node_type):
         if not AZUREParamValidator.validate_vmsize(
                 self.azure_api,
                 config["azure_location"],
-                config["head_node_type"],
+                head_node_type,
         ):
             raise UserReportableException(
                 "VMSize %s does not exist in location %s." %
-                (config["head_node_type"], config["azure_location"]))
+                (head_node_type, config["azure_location"]))
 
         if not AZUREParamValidator.validate_vmsize(
                 self.azure_api,
                 config["azure_location"],
-                config["node_type"]
+                node_type
         ):
             raise UserReportableException(
                 "VMSize %s does not exist in location %s." %
-                (config["node_type"], config["azure_location"])
+                (node_type, config["azure_location"])
             )
 
+    @staticmethod
+    def _validate_vm_gen(head_node_vm_gen, node_vm_gen):
+
+        def is_valid_hyperv_gen(g):
+            return g.upper() in ("V1", "V2")
+
+        if not is_valid_hyperv_gen(head_node_vm_gen):
+            raise UserReportableException(
+                "Invalid head node Hyper-V generation: %r. Supported values: 'V1', 'V2'." % head_node_vm_gen)
+        if not is_valid_hyperv_gen(node_vm_gen):
+            raise UserReportableException(
+                "Invalid node Hyper-V generation: %r. Supported values: 'V1', 'V2'." % node_vm_gen)
+
     def _validate_blob(self):
-        if (config["vhd_url"] and
-                not AZUREParamValidator.validate_custom_blob(config["vhd_url"])):
+        if (config["head_node_image"] and config["head_node_image"].startswith("http") and
+                not AZUREParamValidator.validate_custom_blob(config["head_node_image"])):
             raise UserReportableException("VHD Blob specified does not exist or is unreachable.")
