@@ -21,7 +21,17 @@ import clusterondemand.configuration
 import clusterondemandconfig
 from clusterondemand.command_runner import run_invoked_command
 
-from . import clustercreate, clusterdelete, clusterlist, configdump, configshow, configuration, imagelist, vmsizelist
+from . import (
+    clustercreate,
+    clusterdelete,
+    clusterlist,
+    configdump,
+    configshow,
+    configuration,
+    eula,
+    imagelist,
+    vmsizelist
+)
 
 log = logging.getLogger("cluster-on-demand")
 
@@ -98,4 +108,4 @@ azure_commands.add_command(
 
 
 def cli_main():
-    run_invoked_command(azure_commands)
+    run_invoked_command(azure_commands, pre_run_check=eula.check_azure_eula)
