@@ -44,7 +44,7 @@ class AZUREParamValidator(object):
     @staticmethod
     def validate_custom_blob(blob_url):
         try:
-            StorageAction.get_blob_metadata(blob_url)
+            StorageAction.get_blob_properties(blob_url).metadata
         except Exception:
             return False
         return True
